// Represent data associated with an omelet. Data and non-static
// methods are define together in the typical Java fashion. During
// methods, the variable "this" is defined as the omelet being
// operated on. None of the methods or fields are static.
public class OOOmelet{
  public int eggs;                // How many eggs in the omelet
  public int ozCheese;            // How many ounces of chees
  public String extraIngredients; // Extra ingredients added
  public double totalCookMinutes; // How long the omelet has cooked
  
  // Create a custom-sized omelet. Constructors NEVER return anything
  // and do not allocate memory for the object being constructed
  // though refered to objects like the string below should be
  // allocated.
  public OOOmelet(int eggs,
                  int ozCheese){
    this.eggs = eggs;
    this.ozCheese = ozCheese;
    this.extraIngredients = new String("");
    this.totalCookMinutes = 0.0;
  }
  
  // Construct a standard 3-egg omelet. This method is distinguished
  // from the previous as it takes no arguments.  Notice the strange
  // this(..) syntax which calls another constructor for the current
  // object. Like the other constructor, no return value is required.
  public OOOmelet(){
    this(3, 4);
  }
  
  // Add an extra ingredient to an omelet
  public void addIngredient(String ingredient){
    this.extraIngredients += ingredient + " ";
  }    
  
  // Cook an omelet for the given amount of time
  public void cookFor(double cookMinutes){
    this.totalCookMinutes += cookMinutes;
  }
  
  // Determine if the omelet has been burned while cooking
  public boolean isBurned(){
    return this.totalCookMinutes > 2.0 * this.eggs;
  }
  
  // Determine if consumption of the given omelet is risky
  public boolean foodPoisoningIminent(){
    return this.totalCookMinutes < 1.0 * this.eggs;
  }
  
  // Constants defining calories of standard ingredients in omelets
  public static final int EGG_CALORIES = 94;
  public static final int CHEESE_OZ_CALORIES = 114;
  
  // Calculate the calorie count of the basic omelet ingredients. Does
  // not account for extra ingredients
  public int getBaseCalories(){
    return
      this.eggs     * EGG_CALORIES +
      this.ozCheese * CHEESE_OZ_CALORIES;
  }
  
  // Add a toString() method
  public String toString(){
    return String.format("%d eggs %d oz cheese omelet, cooked for %.1f minutes",
                         this.eggs, this.ozCheese, totalCookMinutes);

    // // Alternative way to construct strings that does not get the
    // // decimal digits correct
    //    return 
    //      this.eggs + " eggs " +
    //      this.ozCheese +
    //      " oz cheese, cooked for " + this.totalCookMinutes +
    //      " minutes";
    //    
  }
  
  // Add an equals(OOOmelet other) method that compares two omelets
  // deeply.  Technically this method does not override the existing
  // equals() method as it takes an OOOmelet rather than an Object as
  // its argument.
  public boolean equals(OOOmelet other){
    if(this.eggs != other.eggs){
      return false;
    }
    if(this.ozCheese != other.ozCheese){
      return false;
    }
    if(!this.extraIngredients.equals(other.extraIngredients)){
      return false;
    }
    return true;
    
  }
  
  // Return the "best" omelet in an array; better omelets have higher
  // calorie counts as reported by the o.getBaseCalories() method.  If
  // the array is empty, return null.
  public static OOOmelet bestOmelet(OOOmelet [] arr){
    if(arr.length == 0){
      return null;
    }
    OOOmelet best = arr[0];
    for(int i=0; i<arr.length; i++){
      if(best.getBaseCalories() < arr[i].getBaseCalories()){
        best = arr[i];
      }
    }
    return best;
  }

}


