// Represent data associated with an omelet. Data and non-static
// methods are define together in the typical Java fashion. During
// methods, the variable "this" is defined as the omelet being
// operated on. None of the methods or fields are static.
//
// This version makes all fields privates and provides accessors
// It also contains proper equals() and toString() methods
public class POmelet{
  private int eggs;                // How many eggs in the omelet
  private int ozCheese;            // How many ounces of chees
  private String extraIngredients; // Extra ingredients added
  private double totalCookMinutes; // How long the omelet has cooked

  // Create a custom-sized omelet. Constructors NEVER return anything
  // and do not allocate memory for the object being constructed
  // though refered to objects like the string below should be
  // allocated.
  public POmelet(int eggs,
                  int ozCheese){
    this.eggs = eggs;
    this.ozCheese = ozCheese;
    this.extraIngredients = new String("");
    this.totalCookMinutes = 0.0;
  }

  // Construct a standard 3-egg omelet. This method is distinguished
  // from the previous as it takes no arguments.  Notice the strange
  // this(..) syntax which calls another constructor for the current
  // object. Like the other constructor, no return value is required.
  public POmelet(){
    this(3, 4);
  }

  // Accessor methods for each field
  public int getEggs(){
    return this.eggs;
  }
  public int getOzCheese(){
    return this.ozCheese;
  }
  public String getExtraIngredients(){
    return this.extraIngredients;
  }
  public double getTotalCookMinutes(){
    return this.totalCookMinutes;
  }

  // Add an extra ingredient to an omelet
  public void addIngredient(String ingredient){
    this.extraIngredients += ingredient + " ";
  }    

  // Cook an omelet for the given amount of time
  public void cookFor(double cookMinutes){
    this.totalCookMinutes += cookMinutes;
  }

  // Determine if the omelet has been burned while cooking
  public boolean isBurned(){
    return this.totalCookMinutes > 2.0 * this.eggs;
  }

  // Determine if consumption of the given omelet is risky
  public boolean foodPoisoningIminent(){
    return this.totalCookMinutes < 1.0 * this.eggs;
  }

  // Constants defining calories of standard ingredients in omelets
  public static final int EGG_CALORIES = 94;
  public static final int CHEESE_OZ_CALORIES = 114;

  // Calculate the calorie count of the basic omelet ingredients. Does
  // not account for extra ingredients
  public int getBaseCalories(){
    return
      this.eggs     * EGG_CALORIES +
      this.ozCheese * CHEESE_OZ_CALORIES;
  }

  // Create a string reprsentation of the omlet
  public String toString(){
    return String.format("%d eggs %d oz cheese, cooked for %.1f minutes",
                         this.eggs,this.ozCheese,this.totalCookMinutes);
  }

  // Equals method defined on size and ingredients of the omelet. Note
  // use of deep equality check of strings
  public boolean equals(POmelet other){
    return
      this.eggs == other.eggs &&
      this.ozCheese == other.ozCheese &&
      this.extraIngredients.equals(other.extraIngredients);
  }

}


